@@ -20,6 +20,7 @@ package main
 import (
 	"bufio"
 	"bytes"
+	"fmt"
 	"internal/system"
 	"internal/system/apt"
 	"io"
@@ -148,8 +149,10 @@ func queryDpkgUpgradeInfoByAptList(sourcePath string) ([]string, error) {
 	if len(ps) == 0 {
 		return nil, nil
 	}
-	cmd := exec.Command("apt", append([]string{"-c", system.LastoreAptV2CommonConfPath, "list", "--upgradable"}, ps...)...) // #nosec G204
-
+	cmd := exec.Command("apt", append([]string{"-c", system.LastoreAptV2CommonConfPath,
+		"-o", fmt.Sprintf("Dir::Etc::SourceList=%s", system.SystemSourceFile),
+		"-o", fmt.Sprintf("Dir::Etc::SourceParts=%s", system.OriginSourceDir),
+		"list", "--upgradable"}, ps...)...) // #nosec G204
 	r, err := cmd.StdoutPipe()
 	if err != nil {
 		return nil, err
